==> doc_transformers-0.1.tar.gz: doc_transformers-0.1/setup.py <==
from distutils.core import setup

try:
    import pypandoc
    long_description = pypandoc.convert('README.md', 'rst')
except(IOError, ImportError):
    long_description = open('README.md').read()

setup(
  name = 'doc_transformers',         # How you named your package folder (MyLib)
  packages = ['doc_transformers'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Deep learning for document processing',   # Give a short description about your library
  long_description=long_description,
  author = 'Vishnu N',                   # Type in your name
  author_email = 'vishnunkumar25@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Vishnunkumar/doc_transformers/',   # Provide either the link to your github or to your website
  download_url ='https://github.com/Vishnunkumar/doc_transformers/archive/refs/tags/v-1.tar.gz',    # I explain this later on
  keywords = ['Documents', 'Machine learning', 'NLP', 'Deep learning', 'Computer Vision'],   # Keywords that define your package best
  install_requires = [ 
          'transformers',
          'pyyaml==5.1',
          'torch==1.8.0',
          'torchvision==0.9.0',
          'datasets',
          'pytesseract'
  ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> doc_transformers-0.2.tar.gz: doc_transformers-0.2/setup.py <==
from distutils.core import setup

setup(
  name = 'doc_transformers',         # How you named your package folder (MyLib)
  packages = ['doc_transformers'],   # Chose the same as "name"
  version = '0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Deep learning for document processing',   # Give a short description about your library
  author = 'Vishnu N',                   # Type in your name
  author_email = 'vishnunkumar25@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Vishnunkumar/doc_transformers/',   # Provide either the link to your github or to your website
  download_url ='https://github.com/Vishnunkumar/doc_transformers/archive/refs/tags/v-2.tar.gz',    # I explain this later on
  keywords = ['Documents', 'Machine learning', 'NLP', 'Deep learning', 'Computer Vision'],   # Keywords that define your package best
  install_requires = [            # I get to this in a second
          'transformers',
          'pyyaml==5.1',
          'torch==1.8.0',
          'torchvision==0.9.0',
          'datasets',
          'pytesseract'
  ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
